# api-client

AT-RTS
- API version: 5.6.0
  - Build date: 2024-06-19T08:12:37.917116Z[Etc/UTC]

# AT-RTS (Remote Translation Service) API Documentation Welcome to the AT-RTS API documentation. AT-RTS is a robust web API designed to integrate our advanced translation systems into client systems, enabling full control over the content translation process. ## API Overview AT-RTS, built on a SOAP web service framework, offers REST interoperability starting from version 5.3.0, facilitating seamless integration into diverse environments. ### Key Functionalities   1. **Operating Check**      Verifies the active status of the service.   2. **Synchronous Translation**      Handles requests for immediate, automated (non-human) translation.   3. **Asynchronous Translation**      Processes orders for specialized professional translations on a deferred basis. Each request generates a unique token to identify and track the translation order. This token is essential for subsequent retrieval and proofreading of the translations.   ### Special Features   - **Callback URL**: Asynchronous translation requests can specify a callback URL to activate a notification service once the translation is complete. This allows clients to automate the download process of completed translations.   - **Translation Return Request**: Using the token from an asynchronous request, clients can retrieve the completed translation. If the translation is not yet complete, the system provides current status information.   - **Cancellation Request**: Allows clients to cancel previously submitted asynchronous translation requests using the token, provided the translation process has not yet commenced.   - **List of Requests**: Offers a comprehensive list detailing the status and usage of translation orders. Each entry includes:   - `projectid`: Unique identifier for the AT project.   - `token`: Token associated with the request.   - `sourcelang`: Source language of the text.   - `targetlang`: Target language for the translation.   - `filename`: File name associated with the request.   - `wordcount`: Total word count of the document.   - `status`: Current status of the translation (with codes such as 10: Under Review, 20: Ready, 30: Delivered, etc.).   - `urlcallback`: Optional URL for receiving completed translations.   - `errnotifiersendto`: Optional email address for receiving notifications on translation errors.   - `dateinsert`: Registration date of the translation request.   - `type`: Specifies whether the translation is SYNCHRONOUS or ASYNCHRONOUS.   ### Reliability Guarantees   ATLS Global ensures reliable return of asynchronous translations to client infrastructures. In the event of communication failures, the system is designed to alert clients through a warning email to the specified contact address, enhancing overall service reliability.   For detailed API usage examples and further technical information, refer to the subsequent sections of this documentation.


*Automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen)*


## Requirements

Building the API client library requires:
1. Java 1.7+
2. Maven/Gradle

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn clean install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn clean deploy
```

Refer to the [OSSRH Guide](http://central.sonatype.org/pages/ossrh-guide.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
  <groupId>com.atls</groupId>
  <artifactId>api-client</artifactId>
  <version>1.0.0</version>
  <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
compile "com.atls:api-client:1.0.0"
```

### Others

At first generate the JAR by executing:

```shell
mvn clean package
```

Then manually install the following JARs:

* `target/api-client-1.0.0.jar`
* `target/lib/*.jar`

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java
import com.atls.api.invoker.*;
import com.atls.api.invoker.auth.*;
import com.atls.api.model.*;
import com.atls.api.RestapiApi;

import java.io.File;
import java.util.*;

public class RestapiApiExample {

    public static void main(String[] args) {
        ApiClient defaultClient = Configuration.getDefaultApiClient();

        // Configure API key authorization: ApiKeyAuth
        ApiKeyAuth ApiKeyAuth = (ApiKeyAuth) defaultClient.getAuthentication("ApiKeyAuth");
        ApiKeyAuth.setApiKey("YOUR API KEY");
        // Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
        //ApiKeyAuth.setApiKeyPrefix("Token");
        // Configure HTTP basic authorization: BasicAuth
        HttpBasicAuth BasicAuth = (HttpBasicAuth) defaultClient.getAuthentication("BasicAuth");
        BasicAuth.setUsername("YOUR USERNAME");
        BasicAuth.setPassword("YOUR PASSWORD");

        RestapiApi apiInstance = new RestapiApi();
        Object body = null; // Object | Document information to be deleted
        try {
            OutFile result = apiInstance.delFileByToken(body);
            System.out.println(result);
        } catch (ApiException e) {
            System.err.println("Exception when calling RestapiApi#delFileByToken");
            e.printStackTrace();
        }
    }
}
import com.atls.api.invoker.*;
import com.atls.api.invoker.auth.*;
import com.atls.api.model.*;
import com.atls.api.RestapiApi;

import java.io.File;
import java.util.*;

public class RestapiApiExample {

    public static void main(String[] args) {
        ApiClient defaultClient = Configuration.getDefaultApiClient();

        // Configure API key authorization: ApiKeyAuth
        ApiKeyAuth ApiKeyAuth = (ApiKeyAuth) defaultClient.getAuthentication("ApiKeyAuth");
        ApiKeyAuth.setApiKey("YOUR API KEY");
        // Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
        //ApiKeyAuth.setApiKeyPrefix("Token");
        // Configure HTTP basic authorization: BasicAuth
        HttpBasicAuth BasicAuth = (HttpBasicAuth) defaultClient.getAuthentication("BasicAuth");
        BasicAuth.setUsername("YOUR USERNAME");
        BasicAuth.setPassword("YOUR PASSWORD");

        RestapiApi apiInstance = new RestapiApi();
        Object body = null; // Object | Example of a revised file request
        try {
            OutFile result = apiInstance.getFileByToken(body);
            System.out.println(result);
        } catch (ApiException e) {
            System.err.println("Exception when calling RestapiApi#getFileByToken");
            e.printStackTrace();
        }
    }
}
import com.atls.api.invoker.*;
import com.atls.api.invoker.auth.*;
import com.atls.api.model.*;
import com.atls.api.RestapiApi;

import java.io.File;
import java.util.*;

public class RestapiApiExample {

    public static void main(String[] args) {
        ApiClient defaultClient = Configuration.getDefaultApiClient();

        // Configure API key authorization: ApiKeyAuth
        ApiKeyAuth ApiKeyAuth = (ApiKeyAuth) defaultClient.getAuthentication("ApiKeyAuth");
        ApiKeyAuth.setApiKey("YOUR API KEY");
        // Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
        //ApiKeyAuth.setApiKeyPrefix("Token");
        // Configure HTTP basic authorization: BasicAuth
        HttpBasicAuth BasicAuth = (HttpBasicAuth) defaultClient.getAuthentication("BasicAuth");
        BasicAuth.setUsername("YOUR USERNAME");
        BasicAuth.setPassword("YOUR PASSWORD");

        RestapiApi apiInstance = new RestapiApi();
        Integer projectid = 56; // Integer | Translation project identifier.
        String sourcelang = "sourcelang_example"; // String | Source language code in ISO-639-3 format.
        String targetlang = "targetlang_example"; // String | Target language code in ISO-639-3 format.
        String datecutoff = "datecutoff_example"; // String | Cut-off date, in the following format: YYYYY-MM-DDTHH:MI:SSZ (UTC or Zulu time).
        String options = "options_example"; // String | JSON auxiliary options.
        try {
            OutList result = apiInstance.getList(projectid, sourcelang, targetlang, datecutoff, options);
            System.out.println(result);
        } catch (ApiException e) {
            System.err.println("Exception when calling RestapiApi#getList");
            e.printStackTrace();
        }
    }
}
import com.atls.api.invoker.*;
import com.atls.api.invoker.auth.*;
import com.atls.api.model.*;
import com.atls.api.RestapiApi;

import java.io.File;
import java.util.*;

public class RestapiApiExample {

    public static void main(String[] args) {
        ApiClient defaultClient = Configuration.getDefaultApiClient();

        // Configure API key authorization: ApiKeyAuth
        ApiKeyAuth ApiKeyAuth = (ApiKeyAuth) defaultClient.getAuthentication("ApiKeyAuth");
        ApiKeyAuth.setApiKey("YOUR API KEY");
        // Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
        //ApiKeyAuth.setApiKeyPrefix("Token");
        // Configure HTTP basic authorization: BasicAuth
        HttpBasicAuth BasicAuth = (HttpBasicAuth) defaultClient.getAuthentication("BasicAuth");
        BasicAuth.setUsername("YOUR USERNAME");
        BasicAuth.setPassword("YOUR PASSWORD");

        RestapiApi apiInstance = new RestapiApi();
        Integer projectid = 56; // Integer | Translation project identifier.
        String token = "token_example"; // String | Token resulting from the asynchronous translation request.
        String options = "options_example"; // String | JSON auxiliary options.
        try {
            OutFile result = apiInstance.getgetFileByToken(projectid, token, options);
            System.out.println(result);
        } catch (ApiException e) {
            System.err.println("Exception when calling RestapiApi#getgetFileByToken");
            e.printStackTrace();
        }
    }
}
import com.atls.api.invoker.*;
import com.atls.api.invoker.auth.*;
import com.atls.api.model.*;
import com.atls.api.RestapiApi;

import java.io.File;
import java.util.*;

public class RestapiApiExample {

    public static void main(String[] args) {
        
        RestapiApi apiInstance = new RestapiApi();
        try {
            InlineResponse200 result = apiInstance.ping();
            System.out.println(result);
        } catch (ApiException e) {
            System.err.println("Exception when calling RestapiApi#ping");
            e.printStackTrace();
        }
    }
}
import com.atls.api.invoker.*;
import com.atls.api.invoker.auth.*;
import com.atls.api.model.*;
import com.atls.api.RestapiApi;

import java.io.File;
import java.util.*;

public class RestapiApiExample {

    public static void main(String[] args) {
        ApiClient defaultClient = Configuration.getDefaultApiClient();

        // Configure API key authorization: ApiKeyAuth
        ApiKeyAuth ApiKeyAuth = (ApiKeyAuth) defaultClient.getAuthentication("ApiKeyAuth");
        ApiKeyAuth.setApiKey("YOUR API KEY");
        // Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
        //ApiKeyAuth.setApiKeyPrefix("Token");
        // Configure HTTP basic authorization: BasicAuth
        HttpBasicAuth BasicAuth = (HttpBasicAuth) defaultClient.getAuthentication("BasicAuth");
        BasicAuth.setUsername("YOUR USERNAME");
        BasicAuth.setPassword("YOUR PASSWORD");

        RestapiApi apiInstance = new RestapiApi();
        Object body = null; // Object | Example of a revised translation
        try {
            OutToken result = apiInstance.translateAsynchronous(body);
            System.out.println(result);
        } catch (ApiException e) {
            System.err.println("Exception when calling RestapiApi#translateAsynchronous");
            e.printStackTrace();
        }
    }
}
import com.atls.api.invoker.*;
import com.atls.api.invoker.auth.*;
import com.atls.api.model.*;
import com.atls.api.RestapiApi;

import java.io.File;
import java.util.*;

public class RestapiApiExample {

    public static void main(String[] args) {
        ApiClient defaultClient = Configuration.getDefaultApiClient();

        // Configure API key authorization: ApiKeyAuth
        ApiKeyAuth ApiKeyAuth = (ApiKeyAuth) defaultClient.getAuthentication("ApiKeyAuth");
        ApiKeyAuth.setApiKey("YOUR API KEY");
        // Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
        //ApiKeyAuth.setApiKeyPrefix("Token");
        // Configure HTTP basic authorization: BasicAuth
        HttpBasicAuth BasicAuth = (HttpBasicAuth) defaultClient.getAuthentication("BasicAuth");
        BasicAuth.setUsername("YOUR USERNAME");
        BasicAuth.setPassword("YOUR PASSWORD");

        RestapiApi apiInstance = new RestapiApi();
        Object body = null; // Object | Example of synchronous machine translation
        try {
            OutFile result = apiInstance.translateSynchronous(body);
            System.out.println(result);
        } catch (ApiException e) {
            System.err.println("Exception when calling RestapiApi#translateSynchronous");
            e.printStackTrace();
        }
    }
}
```

## Documentation for API Endpoints

All URIs are relative to *https://rts.at-ls.com/atrts*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*RestapiApi* | [**delFileByToken**](docs/RestapiApi.md#delFileByToken) | **POST** /delFileByToken | delFileByToken
*RestapiApi* | [**getFileByToken**](docs/RestapiApi.md#getFileByToken) | **POST** /getFileByToken | getFileByToken
*RestapiApi* | [**getList**](docs/RestapiApi.md#getList) | **GET** /getList | getList
*RestapiApi* | [**getgetFileByToken**](docs/RestapiApi.md#getgetFileByToken) | **GET** /getFileByToken | getFileByToken
*RestapiApi* | [**ping**](docs/RestapiApi.md#ping) | **GET** /ping | ping
*RestapiApi* | [**translateAsynchronous**](docs/RestapiApi.md#translateAsynchronous) | **POST** /translateAsynchronous | translateAsynchronous
*RestapiApi* | [**translateSynchronous**](docs/RestapiApi.md#translateSynchronous) | **POST** /translateSynchronous | translateSynchronous

## Documentation for Models

 - [ErrorResponse](docs/ErrorResponse.md)
 - [FileRTS](docs/FileRTS.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse401](docs/InlineResponse401.md)
 - [InlineResponse405](docs/InlineResponse405.md)
 - [InlineResponse503](docs/InlineResponse503.md)
 - [OutFile](docs/OutFile.md)
 - [OutList](docs/OutList.md)
 - [OutToken](docs/OutToken.md)

## Documentation for Authorization

Authentication schemes defined for the API:
### ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-ATRTS-API-Key
- **Location**: HTTP header

### BasicAuth

- **Type**: HTTP basic authentication


## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issues.

## Author

tec@at-ls.com
