/*
 * AT-RTS
 * # AT-RTS (Remote Translation Service) API Documentation Welcome to the AT-RTS API documentation. AT-RTS is a robust web API designed to integrate our advanced translation systems into client systems, enabling full control over the content translation process. ## API Overview AT-RTS, built on a SOAP web service framework, offers REST interoperability starting from version 5.3.0, facilitating seamless integration into diverse environments. ### Key Functionalities   1. **Operating Check**      Verifies the active status of the service.   2. **Synchronous Translation**      Handles requests for immediate, automated (non-human) translation.   3. **Asynchronous Translation**      Processes orders for specialized professional translations on a deferred basis. Each request generates a unique token to identify and track the translation order. This token is essential for subsequent retrieval and proofreading of the translations.   ### Special Features   - **Callback URL**: Asynchronous translation requests can specify a callback URL to activate a notification service once the translation is complete. This allows clients to automate the download process of completed translations.   - **Translation Return Request**: Using the token from an asynchronous request, clients can retrieve the completed translation. If the translation is not yet complete, the system provides current status information.   - **Cancellation Request**: Allows clients to cancel previously submitted asynchronous translation requests using the token, provided the translation process has not yet commenced.   - **List of Requests**: Offers a comprehensive list detailing the status and usage of translation orders. Each entry includes:   - `projectid`: Unique identifier for the AT project.   - `token`: Token associated with the request.   - `sourcelang`: Source language of the text.   - `targetlang`: Target language for the translation.   - `filename`: File name associated with the request.   - `wordcount`: Total word count of the document.   - `status`: Current status of the translation (with codes such as 10: Under Review, 20: Ready, 30: Delivered, etc.).   - `urlcallback`: Optional URL for receiving completed translations.   - `errnotifiersendto`: Optional email address for receiving notifications on translation errors.   - `dateinsert`: Registration date of the translation request.   - `type`: Specifies whether the translation is SYNCHRONOUS or ASYNCHRONOUS.   ### Reliability Guarantees   ATLS Global ensures reliable return of asynchronous translations to client infrastructures. In the event of communication failures, the system is designed to alert clients through a warning email to the specified contact address, enhancing overall service reliability.   For detailed API usage examples and further technical information, refer to the subsequent sections of this documentation.
 *
 * OpenAPI spec version: 5.6.0
 * Contact: tec@at-ls.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */

package com.atls.api.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import io.swagger.v3.oas.annotations.media.Schema;
import java.time.OffsetDateTime;
/**
 * File information
 */
@Schema(description = "File information")
@javax.annotation.Generated(value = "io.swagger.codegen.v3.generators.java.JavaClientCodegen", date = "2024-06-19T08:12:37.917116Z[Etc/UTC]")

public class FileRTS {
  @JsonProperty("token_5")
  private String token5 = null;

  @JsonProperty("token")
  private String token = null;

  @JsonProperty("sourcelang")
  private String sourcelang = null;

  @JsonProperty("targetlang")
  private String targetlang = null;

  @JsonProperty("filename")
  private String filename = null;

  @JsonProperty("wordcount")
  private Integer wordcount = null;

  @JsonProperty("idddv4")
  private String idddv4 = null;

  @JsonProperty("dateinsert")
  private OffsetDateTime dateinsert = null;

  @JsonProperty("auxdata")
  private String auxdata = null;

  @JsonProperty("type")
  private Integer type = null;

  @JsonProperty("projectid")
  private Integer projectid = null;

  @JsonProperty("status")
  private Integer status = null;

  public FileRTS token5(String token5) {
    this.token5 = token5;
    return this;
  }

   /**
   * The token key is a string of alphanumeric characters generated by encryption from the ATLS Global SL system that acts as the unique identifier of the file associated with the asynchronous translation request.
   * @return token5
  **/
  @Schema(description = "The token key is a string of alphanumeric characters generated by encryption from the ATLS Global SL system that acts as the unique identifier of the file associated with the asynchronous translation request.")
  public String getToken5() {
    return token5;
  }

  public void setToken5(String token5) {
    this.token5 = token5;
  }

  public FileRTS token(String token) {
    this.token = token;
    return this;
  }

   /**
   * The token key is a string of alphanumeric characters generated using UUID encryption that acts as the unique identifier of the file associated with the asynchronous translation request.
   * @return token
  **/
  @Schema(description = "The token key is a string of alphanumeric characters generated using UUID encryption that acts as the unique identifier of the file associated with the asynchronous translation request.")
  public String getToken() {
    return token;
  }

  public void setToken(String token) {
    this.token = token;
  }

  public FileRTS sourcelang(String sourcelang) {
    this.sourcelang = sourcelang;
    return this;
  }

   /**
   * The sourcelang key is a source language code in ISO-639-3 format.
   * @return sourcelang
  **/
  @Schema(description = "The sourcelang key is a source language code in ISO-639-3 format.")
  public String getSourcelang() {
    return sourcelang;
  }

  public void setSourcelang(String sourcelang) {
    this.sourcelang = sourcelang;
  }

  public FileRTS targetlang(String targetlang) {
    this.targetlang = targetlang;
    return this;
  }

   /**
   * The targetlang key is a target language code in ISO-639-3 format.
   * @return targetlang
  **/
  @Schema(description = "The targetlang key is a target language code in ISO-639-3 format.")
  public String getTargetlang() {
    return targetlang;
  }

  public void setTargetlang(String targetlang) {
    this.targetlang = targetlang;
  }

  public FileRTS filename(String filename) {
    this.filename = filename;
    return this;
  }

   /**
   * The filename key indicates the name of the file.
   * @return filename
  **/
  @Schema(description = "The filename key indicates the name of the file.")
  public String getFilename() {
    return filename;
  }

  public void setFilename(String filename) {
    this.filename = filename;
  }

  public FileRTS wordcount(Integer wordcount) {
    this.wordcount = wordcount;
    return this;
  }

   /**
   * The wordcount key indicates the number of words in the file that have been translated.
   * @return wordcount
  **/
  @Schema(description = "The wordcount key indicates the number of words in the file that have been translated.")
  public Integer getWordcount() {
    return wordcount;
  }

  public void setWordcount(Integer wordcount) {
    this.wordcount = wordcount;
  }

  public FileRTS idddv4(String idddv4) {
    this.idddv4 = idddv4;
    return this;
  }

   /**
   * The idddv4 key indicates the internal identifier.
   * @return idddv4
  **/
  @Schema(description = "The idddv4 key indicates the internal identifier.")
  public String getIdddv4() {
    return idddv4;
  }

  public void setIdddv4(String idddv4) {
    this.idddv4 = idddv4;
  }

  public FileRTS dateinsert(OffsetDateTime dateinsert) {
    this.dateinsert = dateinsert;
    return this;
  }

   /**
   * The dateinsert key indicates the insertion date of the file.
   * @return dateinsert
  **/
  @Schema(description = "The dateinsert key indicates the insertion date of the file.")
  public OffsetDateTime getDateinsert() {
    return dateinsert;
  }

  public void setDateinsert(OffsetDateTime dateinsert) {
    this.dateinsert = dateinsert;
  }

  public FileRTS auxdata(String auxdata) {
    this.auxdata = auxdata;
    return this;
  }

   /**
   * The auxdata key indicates auxiliary values.
   * @return auxdata
  **/
  @Schema(description = "The auxdata key indicates auxiliary values.")
  public String getAuxdata() {
    return auxdata;
  }

  public void setAuxdata(String auxdata) {
    this.auxdata = auxdata;
  }

  public FileRTS type(Integer type) {
    this.type = type;
    return this;
  }

   /**
   * The type key indicates how the translation has been requested, synchronous or asynchronous.
   * @return type
  **/
  @Schema(description = "The type key indicates how the translation has been requested, synchronous or asynchronous.")
  public Integer getType() {
    return type;
  }

  public void setType(Integer type) {
    this.type = type;
  }

  public FileRTS projectid(Integer projectid) {
    this.projectid = projectid;
    return this;
  }

   /**
   * The key projectid indicates the translation project identifier.
   * @return projectid
  **/
  @Schema(description = "The key projectid indicates the translation project identifier.")
  public Integer getProjectid() {
    return projectid;
  }

  public void setProjectid(Integer projectid) {
    this.projectid = projectid;
  }

  public FileRTS status(Integer status) {
    this.status = status;
    return this;
  }

   /**
   * The status key indicates the status of the translation.
   * @return status
  **/
  @Schema(description = "The status key indicates the status of the translation.")
  public Integer getStatus() {
    return status;
  }

  public void setStatus(Integer status) {
    this.status = status;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    FileRTS fileRTS = (FileRTS) o;
    return Objects.equals(this.token5, fileRTS.token5) &&
        Objects.equals(this.token, fileRTS.token) &&
        Objects.equals(this.sourcelang, fileRTS.sourcelang) &&
        Objects.equals(this.targetlang, fileRTS.targetlang) &&
        Objects.equals(this.filename, fileRTS.filename) &&
        Objects.equals(this.wordcount, fileRTS.wordcount) &&
        Objects.equals(this.idddv4, fileRTS.idddv4) &&
        Objects.equals(this.dateinsert, fileRTS.dateinsert) &&
        Objects.equals(this.auxdata, fileRTS.auxdata) &&
        Objects.equals(this.type, fileRTS.type) &&
        Objects.equals(this.projectid, fileRTS.projectid) &&
        Objects.equals(this.status, fileRTS.status);
  }

  @Override
  public int hashCode() {
    return Objects.hash(token5, token, sourcelang, targetlang, filename, wordcount, idddv4, dateinsert, auxdata, type, projectid, status);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class FileRTS {\n");
    
    sb.append("    token5: ").append(toIndentedString(token5)).append("\n");
    sb.append("    token: ").append(toIndentedString(token)).append("\n");
    sb.append("    sourcelang: ").append(toIndentedString(sourcelang)).append("\n");
    sb.append("    targetlang: ").append(toIndentedString(targetlang)).append("\n");
    sb.append("    filename: ").append(toIndentedString(filename)).append("\n");
    sb.append("    wordcount: ").append(toIndentedString(wordcount)).append("\n");
    sb.append("    idddv4: ").append(toIndentedString(idddv4)).append("\n");
    sb.append("    dateinsert: ").append(toIndentedString(dateinsert)).append("\n");
    sb.append("    auxdata: ").append(toIndentedString(auxdata)).append("\n");
    sb.append("    type: ").append(toIndentedString(type)).append("\n");
    sb.append("    projectid: ").append(toIndentedString(projectid)).append("\n");
    sb.append("    status: ").append(toIndentedString(status)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}
