/*
 * AT-RTS
 * # AT-RTS (Remote Translation Service) API Documentation Welcome to the AT-RTS API documentation. AT-RTS is a robust web API designed to integrate our advanced translation systems into client systems, enabling full control over the content translation process. ## API Overview AT-RTS, built on a SOAP web service framework, offers REST interoperability starting from version 5.3.0, facilitating seamless integration into diverse environments. ### Key Functionalities   1. **Operating Check**      Verifies the active status of the service.   2. **Synchronous Translation**      Handles requests for immediate, automated (non-human) translation.   3. **Asynchronous Translation**      Processes orders for specialized professional translations on a deferred basis. Each request generates a unique token to identify and track the translation order. This token is essential for subsequent retrieval and proofreading of the translations.   ### Special Features   - **Callback URL**: Asynchronous translation requests can specify a callback URL to activate a notification service once the translation is complete. This allows clients to automate the download process of completed translations.   - **Translation Return Request**: Using the token from an asynchronous request, clients can retrieve the completed translation. If the translation is not yet complete, the system provides current status information.   - **Cancellation Request**: Allows clients to cancel previously submitted asynchronous translation requests using the token, provided the translation process has not yet commenced.   - **List of Requests**: Offers a comprehensive list detailing the status and usage of translation orders. Each entry includes:   - `projectid`: Unique identifier for the AT project.   - `token`: Token associated with the request.   - `sourcelang`: Source language of the text.   - `targetlang`: Target language for the translation.   - `filename`: File name associated with the request.   - `wordcount`: Total word count of the document.   - `status`: Current status of the translation (with codes such as 10: Under Review, 20: Ready, 30: Delivered, etc.).   - `urlcallback`: Optional URL for receiving completed translations.   - `errnotifiersendto`: Optional email address for receiving notifications on translation errors.   - `dateinsert`: Registration date of the translation request.   - `type`: Specifies whether the translation is SYNCHRONOUS or ASYNCHRONOUS.   ### Reliability Guarantees   ATLS Global ensures reliable return of asynchronous translations to client infrastructures. In the event of communication failures, the system is designed to alert clients through a warning email to the specified contact address, enhancing overall service reliability.   For detailed API usage examples and further technical information, refer to the subsequent sections of this documentation.
 *
 * OpenAPI spec version: 5.6.0
 * Contact: tec@at-ls.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */

package com.atls.api;

import com.atls.api.model.ErrorResponse;
import com.atls.api.model.InlineResponse200;
import com.atls.api.model.InlineResponse401;
import com.atls.api.model.InlineResponse405;
import com.atls.api.model.InlineResponse503;
import com.atls.api.model.OutFile;
import com.atls.api.model.OutList;
import com.atls.api.model.OutToken;
import org.junit.Test;
import org.junit.Ignore;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * API tests for RestapiApi
 */
@Ignore
public class RestapiApiTest {

    private final RestapiApi api = new RestapiApi();

    /**
     * delFileByToken
     *
     * Method exclusively designed to cancel an asynchronous translation request via a unique token (generated in the asynchronous translation request). A request can only be cancelled if it has not started to be processed. The status key indicates the **status** of the translation. Possible values for asynchronous translations are: - 10: Under review - 20: Ready and to be delivered - 30: Delivered - 40: Deleted - 50: Delivery expired - 90: Document entry error - 100: Processing error  The **filename** key indicates the name of the file, the base64 key indicates the content of the file in base64 if the request is in status 30 (delivered) and the wordcount key indicates the number of words in the file translated. If the document has already been deleted, the errorCode field shall contain the value 404. If the document cannot be deleted because the translation has already been started, the errorCode field will contain the value 403. 
     *
     * @throws ApiException
     *          if the Api call fails
     */
    @Test
    public void delFileByTokenTest() {
        Object body = null;
        OutFile response = api.delFileByToken(body);

        // TODO: test validations
    }
    /**
     * getFileByToken
     *
     * Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). The status key indicates the translation status. The possible values for asynchronous translations are: - 10: Under review - 20: Ready and pending delivery - 30: Delivered - 40: Deleted - 50: Expired delivery - 90: Documental entry error - 100: Processing error  The **filename** key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file. 
     *
     * @throws ApiException
     *          if the Api call fails
     */
    @Test
    public void getFileByTokenTest() {
        Object body = null;
        OutFile response = api.getFileByToken(body);

        // TODO: test validations
    }
    /**
     * getList
     *
     * Request designed to check the status of all requested translation requests, whether synchronous or asynchronous. The results can be filtered using the date of sending the translation order requests, in Zulu format. 
     *
     * @throws ApiException
     *          if the Api call fails
     */
    @Test
    public void getListTest() {
        Integer projectid = null;
        String sourcelang = null;
        String targetlang = null;
        String datecutoff = null;
        String options = null;
        OutList response = api.getList(projectid, sourcelang, targetlang, datecutoff, options);

        // TODO: test validations
    }
    /**
     * getFileByToken
     *
     * Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). To ensure that the operation of this method is correct in the event of a GET type request, the token must be encoded in URL format. The status key indicates the translation status. The possible values for asynchronous translations are: - 10: Under review - 20: Ready and pending delivery - 30: Delivered - 40: Deleted - 50: Expired delivery - 90: Documental entry error - 100: Processing error  The &lt;b&gt;filename&lt;/b&gt; key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file. 
     *
     * @throws ApiException
     *          if the Api call fails
     */
    @Test
    public void getgetFileByTokenTest() {
        Integer projectid = null;
        String token = null;
        String options = null;
        OutFile response = api.getgetFileByToken(projectid, token, options);

        // TODO: test validations
    }
    /**
     * ping
     *
     * Checking that the service is working properly. This method does NOT REQUIRE AUTHENTICATION. 
     *
     * @throws ApiException
     *          if the Api call fails
     */
    @Test
    public void pingTest() {
        InlineResponse200 response = api.ping();

        // TODO: test validations
    }
    /**
     * translateAsynchronous
     *
     * An asynchronous translation request is generated, i.e. a review of a translation completed by a professional from the ATLS Global S.L. LSP division. 
     *
     * @throws ApiException
     *          if the Api call fails
     */
    @Test
    public void translateAsynchronousTest() {
        Object body = null;
        OutToken response = api.translateAsynchronous(body);

        // TODO: test validations
    }
    /**
     * translateSynchronous
     *
     * Synchronous (non-human automatic translation) translation order request. After the request, the service returns the file translated into the specified target language. 
     *
     * @throws ApiException
     *          if the Api call fails
     */
    @Test
    public void translateSynchronousTest() {
        Object body = null;
        OutFile response = api.translateSynchronous(body);

        // TODO: test validations
    }
}
